
*********************************************************************************
*****************  For analysis with survey data        *************************
*********************************************************************************

/* This do file runs the analysis with survey data of Chong et al. 2015. "Does Corruption Information Inspire the Fight or 
Quash the Hope? A Field Experiment in Mexico on Voter Turnout, Choice, and Party Identification. JOP. 
Please contact ana.delao@yale.edu for any questions */


**Call data set
clear
use Chongetal_survey_JOP.dta


/* Replace missing-data code (9 or 99) with missing values */

foreach var of varlist p9 p12 p14 p21b  {
destring `var', replace force
recode `var' (9=.)
} 

foreach var of varlist p31 c d e f g h i k l {
destring `var', replace force
recode `var' (99=.)
}

/*Generating variables for analysis*/
**Demographics
gen women=(c==2)
gen age=d
gen no_edu=(e==1)
gen primary_edu=(e==2)
gen highschool_edu=(e==3|e==4)
gen college_edu=(e==5)
gen income=f
tab g, gen(occupation)
gen religion=(h==1)
gen very_religious=(i==1|i==2)
gen phone=(k==1)
gen cell=(l==1)

**Satisfied with public services
gen insat=(p12>=3)
	replace insat=. if p12==.

**Hear of Fism
gen fism=(p9==1)

**Party Id
gen panid=(p31==1)
gen priid=(p31==3)
gen prdid=(p31==5)

**Party Id of the incumbent in mpio.
gen partyid_inc=.
replace partyid_inc=panid if estado=="Jalisco"
replace partyid_inc=panid if municipality=="CUERNAVACA" | municipality=="CUAUTLA"
replace  partyid_inc=prdid if municipality=="JIUTEPEC"
replace partyid_inc=prdid if estado=="Tabasco" & municipality!="CENTRO"
replace partyid_inc=priid if municipality=="CENTRO"	
replace partyid_inc=. if p31==.	

gen partyid_none=(p31==17)
	replace partyid_none=. if p31==.
gen partyid_challenger=1-partyid_inc
	replace partyid_challenger=0 if partyid_none==1
	replace partyid_challenger=. if p31==.

**Approval of mayor
gen approv_dummy=(p21b==1)

**Municipal government is honest/dishonest
gen corr_yes=(p14==5| p14==4)
gen honest=(p14==1|p14==2)

gen beliefs_honest=. 
replace beliefs_honest=1 if honest==1
replace beliefs_honest=0 if p14==3
replace beliefs_honest=-1 if corr_yes==1

**rename treatment variables
gen t0=(treatment==0)
**Placebo
replace t1=(treatment==1|treatment==2)
**Treatment corruption remains the same


***Dummies for corruption bins 33 66 100**
gen corr33=(t3_info<float(.33))
gen corr66=(t3_info>=float(.33) & t3_info<float(.66))
gen corr100=(t3_info>=float(.66))

**double interactions
gen corr33t=corr33*t3
gen corr66t=corr66*t3
gen corr100t=corr100*t3

**linear and quadratic
gen t3_2=t3_info^2
gen t3Xlinear=t3*t3_info
gen t3Xquad=t3*t3_2

**Define municipalities that are state capitals
gen capital=(municipality=="CENTRO"| municipality=="CUERNAVACA"| municipality=="GUADALAJARA") 

*Define municipalities where fail to treat was more than 30 percent*/
gen fail_tt=(municipality=="CUAUTLA"| municipality=="CRDENAS" | municipality=="HUIMANGUILLO")

/*Vote choices among all respondents*/
gen voto2009_pan=(p29==1)
gen voto2009_pri=(p29==2)
gen voto2009_prd=(p29==3)


gen voto2009=(p29<=8)
replace voto2009=. if p29==99 
replace voto2009=1 if  p29==10
replace voto2009=1 if p29==11 

gen voto2009_inc=.
replace voto2009_inc=voto2009_pan if estado=="Jalisco"
replace voto2009_inc=voto2009_pan if municipality=="CUERNAVACA" | municipality=="CUAUTLA"
replace  voto2009_inc=voto2009_prd if municipality=="JIUTEPEC"
replace voto2009_inc=voto2009_prd if estado=="Tabasco" & municipality!="CENTRO"
replace voto2009_inc=voto2009_pri if municipality=="CENTRO"	
replace voto2009_inc=. if p29==99

gen voto2009_challenger=1-voto2009_inc
	replace voto2009_challenger=0 if voto2009==0
	replace voto2009_challenger=. if p29==99

gen anul2009=(p29==11)
	replace anul2009=. if p29==99
*********************************************************************************
*****************  DESCRIPTIVE STATISTICS WITH SURVEY  ****************
*********************************************************************************

foreach var of varlist women age income no_edu primary_edu highschool_edu occupation1 occupation2 occupation3 occupation4 occupation5 occupation6 occupation7 occupation8 occupation9  religion phone   {
	sum `var' 
}


*********************************************************************************
*****************  Testing validity of randomization WITH SURVEY ****************
*********************************************************************************

/* Table A5. Balance in baseline characteristics-- Comparing means */
 
forval i= 0 (1) 3 {
	sum  women age income no_edu primary_edu highschool_edu occupation1 occupation2 occupation3 occupation4 occupation5 occupation6 occupation7 occupation8 occupation9 occupation10 religion phone if treatment==`i'
}

foreach lhs in women age income phone no_edu primary_edu highschool_edu college_edu occupation1 occupation2 occupation3 occupation4 occupation5 occupation6 occupation7 occupation8 occupation9 occupation10  {
		xi: areg `lhs' t0 t3 , absorb(municipality) cluster(precinct) 
	}

*********************************************************************************
*****************  TABLES WITH SURVEY DATA **************************************
*********************************************************************************

/* Main results use WLS with weights defined by inverse of probability of treatment
 to take into account the block randomization (following Green and Gerber).
 For calculation of weights please see Chong_etal_code.do */ 

/*Did treatment change beliefs and opinions*/
/*Table 3:  Beliefs and Opinions*/

areg corr_yes t0 t3 [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, replace tex ctitle("`x'") dec(2) 2aster
test t3=t0
areg corr_yes t0 t3 t3Xlinear t3Xquad [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, append tex ctitle("`x'") dec(2) 2aster
test t3 t3Xlinear t3Xquad
areg corr_yes t0  corr33t corr66t corr100t [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, append tex ctitle("`x'") dec(2) 2aster
test corr33t corr66t corr100t  

areg honest t0 t3  [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, append tex ctitle("`x'") dec(2) 2aster
test t3=t0
areg honest t0 t3 t3Xlinear t3Xquad [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, append tex ctitle("`x'") dec(2) 2aster
test t3 t3Xlinear t3Xquad
areg honest t0  corr33t corr66t corr100t [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, append tex ctitle("`x'") dec(2) 2aster
test corr33t corr66t corr100t  

areg approv_dummy t0 t3  [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, append tex ctitle("`x'") dec(2) 2aster
test t3=t0
areg approv_dummy t0 t3 t3Xlinear t3Xquad [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, append tex ctitle("`x'") dec(2) 2aster
test t3 t3Xlinear t3Xquad
areg approv_dummy t0  corr33t corr66t corr100t [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, append tex ctitle("`x'") dec(2) 2aster
test corr33t corr66t corr100t  
	
areg insat t0 t3  [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, append tex ctitle("`x'") dec(2) 2aster
test t3=t0
areg insat t0 t3 t3Xlinear t3Xquad  [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, append tex ctitle("`x'") dec(2) 2aster		
test t3 t3Xlinear t3Xquad
areg insat t0  corr33t corr66t corr100t [w=1/q], absorb(municipality) cluster(precinct)
outreg2 using beliefs_w, append tex ctitle("`x'") dec(2) 2aster
test corr33t corr66t corr100t  



/*Did treatment change party id?*/
/*Table 6: Party identifaction*/
	
areg partyid_inc t3 t0 [w=1/q], absorb(municipality) cluster(precinct)
		outreg2 using pid_w, replace tex ctitle("0") dec(2) 2aster
		test t3=t0
areg partyid_inc t3 t3Xlinear t3Xquad t0 [w=1/q], absorb(municipality) cluster(precinct)
        outreg2 using pid_w, append tex ctitle("0") dec(2) 2aster
		test t3 t3Xlinear t3Xquad
areg partyid_inc corr33t corr66t corr100t t0 [w=1/q], absorb(municipality) cluster(precinct)
		outreg2 using pid_w, append tex ctitle("0") dec(2) 	2aster		
	test corr33t=corr66t
	test corr33t=corr100t
	test corr66t=corr100t
	test corr33t corr66t corr100t 	

areg partyid_c t3 t0 [w=1/q], absorb(municipality) cluster(precinct)
		outreg2 using pid_w, append tex ctitle("0") dec(2) 2aster
		test t3=t0
areg partyid_c t3 t3Xlinear t3Xquad t0 [w=1/q], absorb(municipality) cluster(precinct)
        outreg2 using pid_w, append tex ctitle("0") dec(2) 	2aster
		test t3 t3Xlinear t3Xquad
areg partyid_c  corr33t corr66t corr100t t0 [w=1/q], absorb(municipality) cluster(precinct)
		outreg2 using pid_w, append tex ctitle("0") dec(2) 2aster
	test corr33t=corr66t
	test corr33t=corr100t
	test corr66t=corr100t
	test corr33t corr66t corr100t 	

******************************************************
************* Supplemental Information  **************
*******************************************************


/*Table A11. Opinions and beliefs with probits*/

xi: probit corr_yes t0 t3 i.muni [pw=1/q],cluster(precinct)
outreg2 using beliefs_probit, replace tex ctitle("`x'") dec(2) 2aster
xi: probit corr_yes t0 t3 t3Xlinear t3Xquad i.muni [pw=1/q], cluster(precinct)
outreg2 using beliefs_probit, append tex ctitle("`x'") dec(2) 2aster	
xi: probit corr_yes t0  corr33t corr66t corr100t i.muni [pw=1/q], cluster(precinct)
outreg2 using beliefs_probit, append tex ctitle("`x'") dec(2) 2aster
	
xi: probit honest t0 t3 i.muni [pw=1/q],cluster(precinct)
outreg2 using beliefs_probit, append tex ctitle("`x'") dec(2) 2aster
xi: probit honest t0 t3 t3Xlinear t3Xquad i.muni [pw=1/q], cluster(precinct)
outreg2 using beliefs_probit, append tex ctitle("`x'") dec(2) 2aster	
xi: probit honest t0  corr33t corr66t corr100t i.muni [pw=1/q], cluster(precinct)
outreg2 using beliefs_probit, append tex ctitle("`x'") dec(2) 2aster

xi: probit approv_d t0 t3 i.muni [pw=1/q],cluster(precinct)
outreg2 using beliefs_probit, replace tex ctitle("`x'") dec(2) 2aster
xi: probit  approv_d t0 t3 t3Xlinear t3Xquad i.muni [pw=1/q], cluster(precinct)
outreg2 using beliefs_probit, append tex ctitle("`x'") dec(2) 2aster	
xi: probit  approv_d t0  corr33t corr66t corr100t i.muni [pw=1/q], cluster(precinct)
outreg2 using beliefs_probit, append tex ctitle("`x'") dec(2) 2aster
			
xi: probit insat t0 t3 i.muni [pw=1/q],cluster(precinct)
outreg2 using beliefs_probit, append tex ctitle("`x'") dec(2) 2aster
xi: probit insat t0 t3 t3Xlinear t3Xquad i.muni [pw=1/q], cluster(precinct)
outreg2 using beliefs_probit, append tex ctitle("`x'") dec(2) 2aster	
xi: probit insat t0  corr33t corr66t corr100t i.muni [pw=1/q], cluster(precinct)
outreg2 using beliefs_probit, append tex ctitle("`x'") dec(2) 2aster
	

/*Table A12. Party identification with probits*/

xi: probit partyid_inc  t3 t0 i.muni [pw=1/q], cluster(precinct)
		outreg2 using pid_probit, replace tex ctitle("0") dec(2) 2aster
xi: probit partyid_inc  t3 t3Xlinear t3Xquad t0 i.muni [pw=1/q], cluster(precinct)
		outreg2 using pid_probit, append tex ctitle("0") dec(2) 2aster
xi: probit partyid_inc corr33t corr66t corr100t t0 i.muni [pw=1/q], cluster(precinct)
		outreg2 using pid_probit, append tex ctitle("0") dec(2) 2aster
		
xi: probit partyid_c  t3 t0 i.muni [pw=1/q], cluster(precinct)
		outreg2 using pid_probit, append tex ctitle("0") dec(2) 2aster
xi: probit partyid_c  t3 t3Xlinear t3Xquad t0 i.muni [pw=1/q], cluster(precinct)
		outreg2 using pid_probit, append tex ctitle("0") dec(2) 2aster
xi: probit partyid_c   corr33t corr66t corr100t t0 i.muni [pw=1/q], cluster(precinct)
		outreg2 using pid_probit, append tex ctitle("0") dec(2) 2aster

/*Table A13. Self reported turnout and vote choice with baseline controls*/

xi: areg voto2009 t0 t3 ISpoverty t2006 inc_vs2006 challengers_vs2006 i.f i.e i.g women age  religion [pw=1/ponde], absorb(municipality) cluster(precinct)
xi: areg voto2009 t0 corr33t corr66t corr100t ISpoverty t2006 inc_vs2006 challengers_vs2006 i.f i.e i.g women age  religion [pw=1/ponde], absorb(municipality) cluster(precinct)

xi: areg voto2009_inc t0 t3 ISpoverty t2006 inc_vs2006 challengers_vs2006 i.f i.e i.g women age  religion [pw=1/ponde], absorb(municipality) cluster(precinct)
xi: areg voto2009_inc t0 corr33t corr66t corr100t ISpoverty t2006 inc_vs2006 challengers_vs2006 i.f i.e i.g women age  religion [pw=1/ponde], absorb(municipality) cluster(precinct)

xi: areg voto2009_challenger  t0 t3 ISpoverty t2006 inc_vs2006 challengers_vs2006 i.f i.e i.g women age  religion [pw=1/ponde], absorb(municipality) cluster(precinct)
xi: areg voto2009_challenger  t0 corr33t corr66t corr100t  ISpoverty t2006 inc_vs2006 challengers_vs2006 i.f i.e i.g women age  religion [pw=1/ponde], absorb(municipality) cluster(precinct)

xi: areg anul2009 t0 t3 ISpoverty t2006 inc_vs2006 challengers_vs2006 i.f i.e i.g women age  religion [pw=1/ponde], absorb(municipality) cluster(precinct)
xi: areg anul2009  t0 corr33t corr66t corr100t ISpoverty t2006 inc_vs2006 challengers_vs2006 i.f i.e i.g women age  religion [pw=1/ponde], absorb(municipality) cluster(precinct)

	
/*Design-based analysis. Survey respondents are clustered at the precinct level, which is the 
unit of randomization. The following analysis aggregates respondents to precincts, and estimates the 
effects with aggregated data (a la Dunning)*/
sort edo mun precinct
by edo mun precinct: egen ave_partyidnone=mean(partyid_none)
by edo mun precinct: egen ave_partyidinc=mean(partyid_inc)
by edo mun precinct: egen ave_partyidc=mean(partyid_c)


by edo mun precinct: egen ave_approv=mean(approv_dummy)
by edo mun precinct: egen ave_corr=mean(corr_yes)
by edo mun precinct: egen ave_honest=mean(honest)
by edo mun precinct: egen ave_insat=mean(insat)


by edo mun precinct: generate obs_num=_n
drop if obs_num~=1

/*Table A6. Belifs and Opinions with survey data aggregated at the precinct*/
areg ave_corr t3 t0 [w=1/q], abs(municipality) r
outreg2 using ave_beliefs, replace tex ctitle("`x'") dec(2) 2aster
areg ave_corr t3 t3Xlinear t3Xquad t0 [w=1/q], abs(municipality) r
outreg2 using ave_beliefs, append tex ctitle("`x'") dec(2) 2aster
areg ave_corr corr33t corr66t corr100t t0 [w=1/q], abs(municipality) r
outreg2 using ave_beliefs, append tex ctitle("`x'") dec(2) 2aster

areg ave_hon t3 t0 [w=1/q], abs(municipality) r
outreg2 using ave_beliefs, append tex ctitle("`x'") dec(2) 2aster
areg ave_hon t3 t3Xlinear t3Xquad t0 [w=1/q], abs(municipality) r
outreg2 using ave_beliefs, append tex ctitle("`x'") dec(2) 2aster
areg ave_hon corr33t corr66t corr100t t0 [pw=1/ponde], abs(municipality) r
outreg2 using ave_beliefs, append tex ctitle("`x'") dec(2) 2aster

areg ave_approv t3 t0 [w=1/q], abs(municipality) r
outreg2 using ave_beliefs, append tex ctitle("`x'") dec(2) 2aster
areg ave_approv t3 t3Xlinear t3Xquad t0 [w=1/q], abs(municipality) r
outreg2 using ave_beliefs, append tex ctitle("`x'") dec(2) 2aster
areg ave_approv corr33t corr66t corr100t t0 [w=1/q], abs(municipality) r
outreg2 using ave_beliefs, append tex ctitle("`x'") dec(2) 2aster

areg ave_insat t3 t0 [w=1/q], abs(municipality) r 
outreg2 using ave_beliefs, append tex ctitle("`x'") dec(2) 2aster
areg ave_insat t3 t3Xlinear t3Xquad t0 [w=1/q], abs(municipality) r 
outreg2 using ave_beliefs, append tex ctitle("`x'") dec(2) 2aster
areg ave_insat corr33t corr66t corr100t t0 [w=1/q], abs(municipality) r 
outreg2 using ave_beliefs, append tex ctitle("`x'") dec(2) 2aster

/*Table A7. Party id with survey data aggregated at the precinct*/
areg ave_partyidinc t3 t0 [w=1/q], abs(municipality) r
outreg2 using ave_partyid, replace tex ctitle("`x'") dec(2) 2aster
areg ave_partyidinc t3 t3Xlinear t3Xquad t0 [w=1/q], abs(municipality) r
outreg2 using ave_partyid, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidinc corr33t corr66t corr100t t0 [w=1/q], abs(municipality) r
outreg2 using ave_partyid, append tex ctitle("`x'") dec(2) 2aster

areg ave_partyidc t3 t0 [w=1/q], abs(municipality) r
outreg2 using ave_partyid, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidc t3 t3Xlinear t3Xquad t0 [w=1/q], abs(municipality) r
outreg2 using ave_partyid, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidc corr33t corr66t corr100t t0 [w=1/q], abs(municipality) r
outreg2 using ave_partyid, append tex ctitle("`x'") dec(2) 2aster

/*Table A8. Party id with survey data aggregated at the precinct and baseline controls*/

areg ave_partyidinc t3 t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_c, replace tex ctitle("`x'") dec(2) 2aster
areg ave_partyidinc t3 t3Xlinear t3Xquad t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_c, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidinc corr33t corr66t corr100t t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_c, append tex ctitle("`x'") dec(2) 2aster

areg ave_partyidc t3 t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_c, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidc t3 t3Xlinear t3Xquad t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_c, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidc corr33t corr66t corr100t t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_c, append tex ctitle("`x'") dec(2) 2aster


/*Table A9. Party id with survey data aggregated at the precinct without three state capitals*/
areg ave_partyidinc t3 t0 if capital!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_nc, replace tex ctitle("`x'") dec(2) 2aster
areg ave_partyidinc t3 t3Xlinear t3Xquad t0 if capital!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_nc, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidinc corr33t corr66t corr100t t0 if capital!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_nc, append tex ctitle("`x'") dec(2) 2aster

areg ave_partyidc t3 t0 if capital!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_nc, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidc t3 t3Xlinear t3Xquad t0 if capital!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_nc, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidc corr33t corr66t corr100t t0 if capital!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_nc, append tex ctitle("`x'") dec(2) 2aster

/*Table A10. Party id with survey data aggregated at the precinct without mpios where failure to treat was >30 percent*/
areg ave_partyidinc t3 t0 if fail_tt!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_ftt, replace tex ctitle("`x'") dec(2) 2aster
areg ave_partyidinc t3 t3Xlinear t3Xquad t0 if fail_tt!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_ftt, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidinc corr33t corr66t corr100t t0  if fail_tt!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_ftt, append tex ctitle("`x'") dec(2) 2aster

areg ave_partyidc t3 t0  if fail_tt!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_ftt, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidc t3 t3Xlinear t3Xquad t0 if fail_tt!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_ftt, append tex ctitle("`x'") dec(2) 2aster
areg ave_partyidc corr33t corr66t corr100t t0 if fail_tt!=1 [w=1/q], abs(municipality) r
outreg2 using ave_partyid_ftt, append tex ctitle("`x'") dec(2) 2aster

		

/*Graph with survey data*/

/*Party id and treatment dummy*/	   
parmby "areg ave_partyidinc t3 t0 [w=1/q], absorb(municipality)", lab saving(tf1,replace) idn(2) ids(WLS)
parmby "areg ave_partyidinc t3 t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality)", lab saving(tf2,replace) idn(1) ids(With controls)  
parmby "areg ave_partyidinc t3 t0 if capital!=1 [w=1/q], absorb(municipality)", lab saving(tf3,replace) idn(3) ids(Without capitals)
parmby "areg ave_partyidinc t3 t0 if fail_tt!=1 [w=1/q], absorb(municipality)", lab saving(tf4,replace) idn(4) ids(Without mpios>30% fail to treat)

parmby "areg ave_partyidc t3 t0 [w=1/q], absorb(municipality)", lab saving(tf5,replace) idn(6) ids(WLS)
parmby "areg ave_partyidc t3 t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality)", lab saving(tf6,replace) idn(6) ids(With controls)
parmby "areg ave_partyidc t3 t0 if capital!=1 [w=1/q], absorb(municipality)", lab saving(tf7,replace) idn(7) ids(Without capitals)
parmby "areg ave_partyidc t3 t0 if fail_tt!=1 [w=1/q], absorb(municipality)", lab saving(tf8,replace) idn(8) ids(Without mpios>30% fail to treat)

dsconcat tf1 tf2 tf3 tf4 tf5 tf6 tf7 tf8

sencode idstr, gene(modtype)
sencode label, gene(predictor)
lab var modtype "Model"
lab var predictor "Predictor"
drop if predictor!=1

gen depvar=.
replace depvar=1 if idn<=4
replace depvar=2 if idn>4 
label define outcomes 1 "Party id Incumbent" 2 "Party id Challengers"
label values depvar outcomes
 
eclplot estimate min95 max95 depvar, hor supby(modtype, spaceby(0.25))



